library IEEE;
use IEEE.std_logic_1164.all;

Package Digital_Designs is

     type reg_array is array (natural range <>) of std_logic_vector(31 downto 0);
	  
	  function parity (number : std_logic_vector) return std_logic;
	  
	  function pchk (number1, number2 : std_logic_vector) return Boolean;
	  
	  procedure sevenseg (
		signal number 	: in 	std_logic_vector;
		signal hex		: out	std_logic_vector
		);
end Package;

Package body Digital_Designs is

	function parity (number : std_logic_vector)
                 return std_logic is
		variable P : std_logic := '0';
	begin
		for i in number'range loop
			P := P xor number(i);
		end loop;
		return P;
	end parity;

	function pchk (number1, number2 : std_logic_vector)
                 return Boolean is
		variable P1, P2 : std_logic := '0';
	begin
		P1 := parity(number1);
		P2 := parity(number2);
		return P1 = P2;
	end pchk;
	
	procedure sevenseg (
		signal number 	: in 	std_logic_vector;
		signal hex		: out	std_logic_vector
		) is
	begin
		case number is
			when "0000" => hex <= "1000000";
         when "0001" => hex <= "1111001";
         when "0010" => hex <= "0100100";
         when "0011" => hex <= "0110000";
         when "0100" => hex <= "0011001";
         when "0101" => hex <= "0010010";
         when "0110" => hex <= "0000010";
         when "0111" => hex <= "1111000";
         when "1000" => hex <= "0000000";
         when "1001" => hex <= "0011000";
         when "1010" => hex <= "0001000";
         when "1011" => hex <= "0000011";
         when "1100" => hex <= "1000110";
         when "1101" => hex <= "0100001";
         when "1110" => hex <= "0000110";
         when others => hex <= "0001110";
		end case;
	end sevenseg;	
end Package body;

